Structs
- Background
Fixed Update Plugin - Fixed
Main - Schedule running
PreWriteBack,WriteBackandPostWriteBackonly if it received its data from theWorkTaskpresent in the single Entity containing it. - Handle
Task - Schedule handling a single task.
- Post
Write Back - Called after the propagation of the task result to the ECS.
- PreWrite
Back - Executes before the task result is propagated to the ECS.
- Spawn
Task - Spawn a new background task.
- Substep
Count - Amount of times we simulate the task each fixed frame. Typically used to have a more accurate simulation, by having a smaller timestep, Or catch back with the rendering time, by having a bigger substep count.
- Task
Result - The result of a task to be handled.
- Task
Result Raw - The result of a task to be handled.
- Task
Results - The result of a task to be handled.
- Task
ToRender Time - Difference between tasks and rendering time
- Task
Worker - Struct to be able to configure what the task should do.
- Timestep
- Time simulated by the task each fixed frame.
- Work
Task - The task inside this component is polled before
FixedMain. - Write
Back - Propagates the task result to the ECS.
Enums
Traits
Functions
- extract
- finish_
task_ and_ store_ result - This system queries for
WorkTaskcomponent. It polls the task, if it has finished, it removes theWorkTaskcomponent from the entity, and adds aTaskResultcomponent. - spawn_
task - This system spawns a
WorkTaskis none are ongoing. The task simulate computationally intensive work that potentially spans multiple frames/ticks.